mdt.library.opencl_routines.optimizing package
==============================================

Submodules
----------

mdt.library.opencl_routines.optimizing.AbstractOptimizer module
---------------------------------------------------------------

.. automodule:: mdt.library.opencl_routines.optimizing.AbstractOptimizer
    :members:
    :undoc-members:
    :show-inheritance:

mdt.library.opencl_routines.optimizing.GridSearch module
--------------------------------------------------------

.. automodule:: mdt.library.opencl_routines.optimizing.GridSearch
    :members:
    :undoc-members:
    :show-inheritance:

mdt.library.opencl_routines.optimizing.LevenbergMarquardt module
----------------------------------------------------------------

.. automodule:: mdt.library.opencl_routines.optimizing.LevenbergMarquardt
    :members:
    :undoc-members:
    :show-inheritance:

mdt.library.opencl_routines.optimizing.MetaOptimizer module
-----------------------------------------------------------

.. automodule:: mdt.library.opencl_routines.optimizing.MetaOptimizer
    :members:
    :undoc-members:
    :show-inheritance:

mdt.library.opencl_routines.optimizing.NMSimplex module
-------------------------------------------------------

.. automodule:: mdt.library.opencl_routines.optimizing.NMSimplex
    :members:
    :undoc-members:
    :show-inheritance:

mdt.library.opencl_routines.optimizing.Powell module
----------------------------------------------------

.. automodule:: mdt.library.opencl_routines.optimizing.Powell
    :members:
    :undoc-members:
    :show-inheritance:

mdt.library.opencl_routines.optimizing.SerialBFGS module
--------------------------------------------------------

.. automodule:: mdt.library.opencl_routines.optimizing.SerialBFGS
    :members:
    :undoc-members:
    :show-inheritance:

mdt.library.opencl_routines.optimizing.SerialLM module
------------------------------------------------------

.. automodule:: mdt.library.opencl_routines.optimizing.SerialLM
    :members:
    :undoc-members:
    :show-inheritance:

mdt.library.opencl_routines.optimizing.SerialPowell module
----------------------------------------------------------

.. automodule:: mdt.library.opencl_routines.optimizing.SerialPowell
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: mdt.library.opencl_routines.optimizing
    :members:
    :undoc-members:
    :show-inheritance:
